/*********************************************************************
*                    SEGGER Microcontroller GmbH                     *
*        Solutions for real time microcontroller applications        *
**********************************************************************
*                                                                    *
*        (c) 1996 - 2020  SEGGER Microcontroller GmbH                *
*                                                                    *
*        Internet: www.segger.com    Support:  support@segger.com    *
*                                                                    *
**********************************************************************

** emWin V6.10 - Graphical user interface for embedded applications **
emWin is protected by international copyright laws.   Knowledge of the
source code may not be used to write a similar product.  This file may
only  be used  in accordance  with  a license  and should  not be  re-
distributed in any way. We appreciate your understanding and fairness.
----------------------------------------------------------------------
File        : GUI_MEMDEV_BlurringAndBlending.c
Purpose     : Sample that shows how blurring and blending operations
              are done in emWin using memory devices.
Requirements: WindowManager - (x)
              MemoryDevices - (x)
              AntiAliasing  - ( )
              VNC-Server    - ( )
              PNG-Library   - ( )
              TrueTypeFonts - ( )
---------------------------END-OF-HEADER------------------------------
*/

#include "DIALOG.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

#define BLURRING_DEPTH      3         // should be between 1 and 10

#define BLENDING_COLOR      GUI_RED
#define BLENDING_INTENSITY  110       // should be between 0 (no blending) and 255 (full blending)

/*********************************************************************
*
*       Static data
*
**********************************************************************
*/
/*********************************************************************
*
*       acseggerlogo
*/
const unsigned char acseggerlogo[5688UL + 1] = {
  0xFF, 0xD8, 0xFF, 0xE0, 0x00, 0x10, 0x4A, 0x46, 0x49, 0x46, 0x00, 0x01, 0x01, 0x01, 0x00, 0x5A, 0x00, 0x5A, 0x00, 0x00, 0xFF, 0xDB, 0x00, 0x43, 0x00, 0x03, 0x02, 0x02, 0x03, 0x02, 0x02, 0x03, 0x03, 0x03, 0x03, 0x04, 0x03, 0x03, 0x04, 0x05,
  0x08, 0x05, 0x05, 0x04, 0x04, 0x05, 0x0A, 0x07, 0x07, 0x06, 0x08, 0x0C, 0x0A, 0x0C, 0x0C, 0x0B, 0x0A, 0x0B, 0x0B, 0x0D, 0x0E, 0x12, 0x10, 0x0D, 0x0E, 0x11, 0x0E, 0x0B, 0x0B, 0x10, 0x16, 0x10, 0x11, 0x13, 0x14, 0x15, 0x15, 0x15, 0x0C, 0x0F,
  0x17, 0x18, 0x16, 0x14, 0x18, 0x12, 0x14, 0x15, 0x14, 0xFF, 0xDB, 0x00, 0x43, 0x01, 0x03, 0x04, 0x04, 0x05, 0x04, 0x05, 0x09, 0x05, 0x05, 0x09, 0x14, 0x0D, 0x0B, 0x0D, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14,
  0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0xFF, 0xC2,
  0x00, 0x11, 0x08, 0x00, 0x4B, 0x00, 0x96, 0x03, 0x01, 0x11, 0x00, 0x02, 0x11, 0x01, 0x03, 0x11, 0x01, 0xFF, 0xC4, 0x00, 0x1C, 0x00, 0x01, 0x00, 0x02, 0x02, 0x03, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06,
  0x07, 0x05, 0x08, 0x01, 0x02, 0x04, 0x03, 0xFF, 0xC4, 0x00, 0x1B, 0x01, 0x01, 0x01, 0x00, 0x03, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x05, 0x03, 0x04, 0x06, 0x01, 0x02, 0x07, 0xFF, 0xDA, 0x00, 0x0C,
  0x03, 0x01, 0x00, 0x02, 0x10, 0x03, 0x10, 0x00, 0x00, 0x01, 0xF1, 0x13, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x0A, 0x4E, 0x89, 0x0D, 0xD8, 0x53, 0x89, 0xF4, 0x3C, 0x19, 0x31, 0xCE, 0xE7, 0x51, 0x00, 0x00, 0x00, 0x00, 0x01, 0xA4, 0xC5,
  0xAA, 0x49, 0xED, 0xC4, 0xC9, 0xE2, 0xCB, 0x5C, 0x55, 0x97, 0x7D, 0x73, 0x7D, 0x1E, 0x5F, 0x06, 0x70, 0x00, 0x00, 0x00, 0x00, 0xD2, 0x62, 0xD1, 0xF7, 0xCB, 0x1A, 0x94, 0xDA, 0xE2, 0xAC, 0xAB, 0x76, 0x25, 0xBA, 0x5A, 0xFC, 0x1B, 0xAF, 0x9F,
  0xBE, 0x00, 0x00, 0x00, 0x00, 0xC9, 0xE2, 0xCB, 0xA7, 0xB8, 0x33, 0xDA, 0x1E, 0xFC, 0xD5, 0x9F, 0xA0, 0x70, 0x5B, 0x95, 0xC1, 0xF7, 0x3A, 0xF1, 0xD4, 0x73, 0x37, 0x9F, 0x3B, 0xD0, 0xD7, 0x95, 0x26, 0x00, 0x00, 0x00, 0x00, 0x25, 0x7A, 0x5B,
  0x9A, 0xC9, 0x36, 0x95, 0xA1, 0xEF, 0xCF, 0xDB, 0xA6, 0xE6, 0xE5, 0xBA, 0x3B, 0xBF, 0x6F, 0x9F, 0xA8, 0x2D, 0x29, 0xDF, 0x5F, 0x9F, 0xA0, 0x00, 0x00, 0x00, 0x04, 0xD7, 0x43, 0x7F, 0x5D, 0xA3, 0xD7, 0xB5, 0x1E, 0x5B, 0x7B, 0x9A, 0x95, 0x45,
  0xA8, 0xD2, 0x0D, 0x6D, 0x9C, 0xCE, 0xBE, 0x7A, 0xE2, 0x55, 0x59, 0xE9, 0x5D, 0x16, 0x91, 0x5E, 0x19, 0xE3, 0xB9, 0x88, 0x25, 0x84, 0x50, 0xC9, 0x98, 0x52, 0x7E, 0x6B, 0x59, 0x6A, 0x3C, 0xC7, 0x75, 0x9C, 0xAD, 0xCF, 0x06, 0xED, 0x6F, 0x56,
  0x5D, 0xEF, 0xCE, 0x74, 0x5A, 0xA6, 0x70, 0x40, 0xCB, 0xE0, 0xAF, 0x08, 0xE1, 0x35, 0x3B, 0x18, 0xB3, 0x16, 0x4A, 0x4E, 0x0B, 0x08, 0xA1, 0x0B, 0x30, 0xD8, 0x2F, 0x7E, 0x7B, 0x3D, 0xED, 0xE3, 0x97, 0xB8, 0x23, 0xD2, 0x78, 0xCF, 0xB1, 0xC1,
  0xE7, 0x33, 0x26, 0x04, 0xC9, 0x98, 0xD3, 0xDE, 0x65, 0x0F, 0x29, 0xA7, 0xA7, 0xB8, 0xD7, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0x78, 0x8F, 0xFF, 0xC4, 0x00, 0x25, 0x10, 0x00, 0x01, 0x03, 0x04, 0x03, 0x00, 0x01, 0x05, 0x01, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x05, 0x00, 0x04, 0x06, 0x02, 0x03, 0x07, 0x17, 0x01, 0x16, 0x36, 0x13, 0x11, 0x14, 0x15, 0x21, 0x30, 0x40, 0xFF, 0xDA, 0x00, 0x08, 0x01, 0x01, 0x00, 0x01, 0x05, 0x02, 0x02, 0x02, 0xBC, 0xA5, 0x7B, 0x49, 0x87,
  0x5A, 0x4C, 0x3A, 0xD2, 0x61, 0xD6, 0x93, 0x0E, 0xB4, 0x98, 0x75, 0xA4, 0xC3, 0xAD, 0x26, 0x1D, 0x69, 0x30, 0xEB, 0x49, 0x87, 0x5A, 0x4C, 0x3A, 0xD2, 0x61, 0xD6, 0x93, 0x0E, 0xB4, 0x98, 0x75, 0xA4, 0xC3, 0xAD, 0x26, 0x1D, 0x69, 0x30, 0xEB,
  0x49, 0x87, 0x57, 0x4B, 0x3A, 0xC5, 0x27, 0xF0, 0xA7, 0x9A, 0x8F, 0xCC, 0x5C, 0xDC, 0x31, 0x28, 0x7A, 0xF0, 0x78, 0x68, 0x9C, 0x96, 0x99, 0x03, 0x2F, 0xED, 0x99, 0xFD, 0x5E, 0x14, 0xF3, 0x73, 0xB8, 0xD7, 0xDF, 0xD9, 0x86, 0x49, 0x38, 0x38,
  0xC8, 0xF8, 0xCB, 0xF0, 0xD3, 0x22, 0x8A, 0x59, 0x30, 0xC7, 0xFA, 0xE6, 0x7F, 0x57, 0x86, 0x3F, 0x51, 0x78, 0x74, 0x93, 0x83, 0xAC, 0x65, 0x22, 0x2F, 0x46, 0x0A, 0xB4, 0x72, 0xCE, 0x5A, 0x10, 0x7B, 0xA7, 0x10, 0x33, 0xDD, 0xA8, 0x42, 0xED,
  0x42, 0x17, 0x6A, 0x10, 0xBB, 0x50, 0x85, 0xDA, 0x84, 0x2E, 0xD4, 0x21, 0x76, 0xA1, 0x0B, 0xB5, 0x08, 0x5D, 0xA8, 0x42, 0xED, 0x42, 0x17, 0x6A, 0x10, 0xBB, 0x50, 0x84, 0xC8, 0xBB, 0x22, 0x55, 0x66, 0x7F, 0x57, 0x86, 0x3C, 0xB0, 0xA2, 0x37,
  0xC5, 0x3F, 0xAE, 0xCD, 0x04, 0xC7, 0xC6, 0x9C, 0xDC, 0x07, 0x2C, 0x3C, 0x05, 0xA9, 0xE6, 0xDA, 0xE0, 0x6A, 0xD7, 0x03, 0x56, 0xB8, 0x1A, 0xB5, 0xC0, 0xD5, 0xAE, 0x06, 0xAD, 0x70, 0x35, 0x6B, 0x81, 0xAB, 0x5C, 0x0D, 0x5A, 0xE0, 0x6A, 0xD7,
  0x03, 0x56, 0xB8, 0x1A, 0xB5, 0xC0, 0xD5, 0x1E, 0x89, 0x33, 0x04, 0xE7, 0x33, 0xFA, 0xBC, 0x31, 0xE5, 0xA0, 0x11, 0x8F, 0x9A, 0xB9, 0xCC, 0x9B, 0xF1, 0x6D, 0xA1, 0x11, 0x9F, 0xC3, 0xB4, 0x94, 0x99, 0xBD, 0x27, 0x29, 0xAB, 0xDC, 0x2D, 0x5E,
  0xE1, 0x6A, 0xF7, 0x0B, 0x57, 0xB8, 0x5A, 0xBD, 0xC2, 0xD5, 0xEE, 0x16, 0xAF, 0x70, 0xB5, 0x7B, 0x85, 0xAB, 0xDC, 0x2D, 0x5E, 0xE1, 0x6A, 0xF7, 0x0B, 0x57, 0xB8, 0x51, 0x58, 0x75, 0xC8, 0xF3, 0xCC, 0xCF, 0xEA, 0xF0, 0xAF, 0x1F, 0x58, 0xD1,
  0xC2, 0xF6, 0x23, 0x62, 0xA1, 0xA0, 0xEE, 0x9A, 0x7F, 0x3A, 0x93, 0x72, 0xD2, 0xDC, 0x32, 0x33, 0xC0, 0x36, 0x6D, 0x64, 0xE7, 0x65, 0xC7, 0x22, 0xCE, 0xA4, 0xB4, 0x13, 0x1F, 0x22, 0x95, 0x49, 0x4E, 0xC7, 0xDB, 0x49, 0xEC, 0xBC, 0xB5, 0x2A,
  0x3B, 0x34, 0x2C, 0x35, 0xF4, 0xB0, 0x51, 0xD9, 0x74, 0xC5, 0xEB, 0x43, 0x2F, 0xBB, 0xD0, 0x1B, 0x53, 0x19, 0x23, 0xC0, 0xD0, 0xE1, 0xBC, 0x4E, 0x49, 0x8F, 0x97, 0x1F, 0x33, 0x14, 0x87, 0x73, 0x76, 0x73, 0x48, 0x88, 0x1C, 0x9A, 0xE4, 0xAC,
  0x0E, 0x67, 0xF5, 0x78, 0x57, 0xF5, 0x1A, 0xA6, 0x97, 0x13, 0xF9, 0x09, 0xE2, 0x34, 0xC6, 0x81, 0xC2, 0x23, 0xD5, 0xBB, 0xBE, 0x9E, 0xD3, 0x11, 0x91, 0x9A, 0x85, 0x3C, 0x70, 0xC6, 0x72, 0x35, 0x98, 0x07, 0x52, 0x78, 0x75, 0xA8, 0x9B, 0x27,
  0x98, 0xF8, 0xD5, 0x88, 0x3B, 0xF3, 0xD2, 0x0A, 0xD9, 0x9B, 0x94, 0x5C, 0xAA, 0x27, 0x93, 0x27, 0x52, 0x76, 0x0F, 0x2D, 0x94, 0x7C, 0xE0, 0x96, 0x1C, 0x12, 0x26, 0x09, 0x70, 0x5E, 0x44, 0xBE, 0x3E, 0xFE, 0x3C, 0x29, 0x00, 0xAE, 0x88, 0x86,
  0x2A, 0x79, 0x4B, 0xB8, 0x76, 0x67, 0xF5, 0x78, 0x69, 0xCD, 0xA6, 0xE2, 0xAD, 0xFC, 0x16, 0x95, 0x7C, 0xD9, 0xBB, 0x47, 0x17, 0x2D, 0xF1, 0xC7, 0xCD, 0x42, 0x20, 0x1C, 0x51, 0x6A, 0x98, 0x31, 0x1E, 0x2A, 0xDD, 0xF0, 0x81, 0xDD, 0x5D, 0x68,
  0x28, 0x53, 0x0B, 0xA4, 0x85, 0x0C, 0x31, 0xC5, 0xB0, 0x21, 0xAD, 0x36, 0x73, 0x6D, 0xAB, 0xDB, 0x2C, 0xA3, 0xA1, 0x07, 0x5D, 0xB6, 0x3C, 0x75, 0x96, 0x3D, 0x70, 0x12, 0xA8, 0x60, 0xCA, 0xD9, 0xFD, 0x6C, 0xFC, 0x6C, 0xDB, 0xB3, 0x1D, 0x67,
  0x28, 0xD3, 0xC9, 0xD9, 0x8E, 0x62, 0x12, 0xD1, 0x91, 0x2F, 0xF0, 0xE2, 0x71, 0x2D, 0x1B, 0x01, 0xFF, 0xC4, 0x00, 0x2D, 0x11, 0x00, 0x00, 0x06, 0x01, 0x02, 0x05, 0x03, 0x02, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x02,
  0x03, 0x04, 0x52, 0x15, 0x14, 0x31, 0x05, 0x11, 0x12, 0x13, 0x32, 0x10, 0x21, 0x40, 0x81, 0xF0, 0x23, 0x30, 0x50, 0x61, 0x62, 0x91, 0xD1, 0xFF, 0xDA, 0x00, 0x08, 0x01, 0x03, 0x01, 0x01, 0x3F, 0x01, 0xF8, 0x91, 0xA7, 0x2C, 0xDD, 0x36, 0x9F,
  0xF6, 0x31, 0x2D, 0xC7, 0x1A, 0x68, 0xD4, 0xDE, 0xE2, 0x1C, 0xA2, 0x92, 0x8F, 0x7F, 0x22, 0xF8, 0x3C, 0x46, 0x27, 0x70, 0xBB, 0xA8, 0xDC, 0x84, 0x19, 0x5A, 0x84, 0x74, 0xAB, 0xC8, 0x84, 0x96, 0x95, 0x05, 0xE2, 0x79, 0xAD, 0xBE, 0xFD, 0x83,
  0x2E, 0xA5, 0xF4, 0x12, 0xD3, 0xF9, 0xE7, 0xB0, 0x83, 0x2B, 0x50, 0x8E, 0x4A, 0xF2, 0x21, 0x31, 0x95, 0x44, 0x74, 0x9F, 0x6B, 0x60, 0x85, 0x37, 0x35, 0x9F, 0xD8, 0xC3, 0x6B, 0x5F, 0x0E, 0x7F, 0xA1, 0x7E, 0x27, 0xF7, 0xCC, 0x6B, 0x23, 0xDC,
  0x86, 0xB2, 0x3D, 0xC8, 0x6B, 0x23, 0xDC, 0x86, 0xB2, 0x3D, 0xC8, 0x6B, 0x23, 0xDC, 0x86, 0xB2, 0x3D, 0xC8, 0x6B, 0x23, 0xDC, 0x86, 0xB2, 0x3D, 0xC8, 0x6B, 0x23, 0xDC, 0x86, 0xB2, 0x3D, 0xC8, 0x6B, 0x23, 0xDC, 0x86, 0xB2, 0x3D, 0xC8, 0x36,
  0xF3, 0x6E, 0xF8, 0x2B, 0x9F, 0xA1, 0xEC, 0x19, 0x75, 0x4C, 0xAC, 0x96, 0x80, 0x69, 0x27, 0x51, 0xC9, 0x65, 0xB8, 0x8A, 0xA3, 0x8F, 0x2B, 0xB4, 0x83, 0xE6, 0x46, 0x24, 0x46, 0x44, 0x94, 0xF2, 0x58, 0xC5, 0xB3, 0x61, 0x8B, 0x66, 0xC3, 0x16,
  0xCD, 0x86, 0x2D, 0x9B, 0x0C, 0x5B, 0x36, 0x18, 0xB6, 0x6C, 0x31, 0x6C, 0xD8, 0x62, 0xD9, 0xB0, 0xC5, 0xB3, 0x61, 0x8B, 0x66, 0xC3, 0x16, 0xCD, 0x86, 0x2D, 0x9B, 0x08, 0xD0, 0x9B, 0x8E, 0xAE, 0xA4, 0x9F, 0x3F, 0x43, 0xD8, 0x70, 0xD8, 0x9D,
  0x5F, 0x8C, 0xBF, 0xA0, 0xE2, 0x12, 0xFB, 0x29, 0xED, 0xA3, 0x73, 0x1C, 0x3E, 0x27, 0x61, 0x3D, 0x6B, 0xF2, 0x31, 0x2D, 0xF5, 0x4B, 0x73, 0xB0, 0xD6, 0xC3, 0x10, 0xBB, 0x8C, 0x42, 0xAE, 0x31, 0x0A, 0xB8, 0xC4, 0x2A, 0xE3, 0x10, 0xAB, 0x8C,
  0x42, 0xAE, 0x31, 0x0A, 0xB8, 0xC4, 0x2A, 0xE3, 0x10, 0xAB, 0x8C, 0x42, 0xAE, 0x31, 0x0A, 0xB8, 0xC4, 0x2A, 0xE2, 0x1C, 0x13, 0x8C, 0xB3, 0x51, 0xAB, 0xD6, 0x43, 0xC9, 0x8A, 0xD7, 0x3F, 0xE8, 0x41, 0x8E, 0xA7, 0xD7, 0xA9, 0x74, 0x71, 0x19,
  0x7D, 0x05, 0xD9, 0x46, 0xE6, 0x20, 0xC4, 0xD3, 0xA7, 0xA9, 0x5E, 0x47, 0xF0, 0x0B, 0xAF, 0x89, 0x3F, 0xFC, 0x48, 0x48, 0x74, 0xA2, 0x33, 0xCD, 0x24, 0x38, 0x7C, 0x63, 0x59, 0xEA, 0x1D, 0xFA, 0x7F, 0xBF, 0x04, 0x88, 0x8B, 0x60, 0x64, 0x47,
  0xEC, 0x7F, 0xA2, 0x7F, 0xFF, 0xC4, 0x00, 0x2D, 0x11, 0x00, 0x00, 0x06, 0x01, 0x02, 0x05, 0x03, 0x02, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x02, 0x03, 0x04, 0x52, 0x15, 0x14, 0x31, 0x05, 0x11, 0x12, 0x13, 0x32, 0x10,
  0x21, 0x40, 0x81, 0xF0, 0x23, 0x30, 0x50, 0x61, 0x62, 0x91, 0xD1, 0xFF, 0xDA, 0x00, 0x08, 0x01, 0x02, 0x01, 0x01, 0x3F, 0x01, 0xF8, 0x92, 0x60, 0xA0, 0x9A, 0x27, 0x98, 0xF7, 0x21, 0x0D, 0xB6, 0xDD, 0x78, 0x90, 0xEE, 0xC2, 0x6C, 0x43, 0x8C,
  0xBF, 0x6F, 0x13, 0xF8, 0x3C, 0x3A, 0x5F, 0x6C, 0xFB, 0x2B, 0xD8, 0xC4, 0xF8, 0x9A, 0x75, 0xF5, 0x27, 0xC4, 0xC4, 0x67, 0x53, 0x3D, 0x93, 0x65, 0xDD, 0xFE, 0xFD, 0xC3, 0xCC, 0xA9, 0x85, 0x9A, 0x15, 0xF9, 0xE5, 0xB8, 0x9D, 0x13, 0x4E, 0xBE,
  0x69, 0xF1, 0x31, 0x0D, 0xF4, 0xCC, 0x68, 0xE3, 0xBD, 0xB8, 0x5A, 0x1C, 0x84, 0xF7, 0xEE, 0x41, 0xD4, 0x23, 0x89, 0x31, 0xD6, 0x8F, 0x22, 0xFB, 0xE4, 0x34, 0x72, 0x28, 0x63, 0x47, 0x22, 0x86, 0x34, 0x72, 0x28, 0x63, 0x47, 0x22, 0x86, 0x34,
  0x72, 0x28, 0x63, 0x47, 0x22, 0x86, 0x34, 0x72, 0x28, 0x63, 0x47, 0x22, 0x86, 0x34, 0x72, 0x28, 0x63, 0x47, 0x22, 0x86, 0x34, 0x72, 0x28, 0x63, 0x47, 0x22, 0x86, 0x1C, 0x61, 0xC6, 0xBC, 0xD3, 0xCB, 0xD0, 0xB7, 0x0F, 0x34, 0x97, 0x90, 0x68,
  0x58, 0x25, 0x1B, 0x2E, 0x73, 0x41, 0xEC, 0x25, 0xA0, 0xA4, 0x45, 0xEE, 0xAC, 0xB9, 0x19, 0x08, 0xD2, 0x57, 0x19, 0x5C, 0xD0, 0x32, 0xAF, 0x50, 0x65, 0x5E, 0xA0, 0xCA, 0xBD, 0x41, 0x95, 0x7A, 0x83, 0x2A, 0xF5, 0x06, 0x55, 0xEA, 0x0C, 0xAB,
  0xD4, 0x19, 0x57, 0xA8, 0x32, 0xAF, 0x50, 0x65, 0x5E, 0xA0, 0xCA, 0xBD, 0x41, 0x95, 0x7A, 0x82, 0x54, 0xD7, 0x24, 0x27, 0xA1, 0x45, 0xCB, 0xD0, 0xB7, 0x1C, 0x4E, 0x5F, 0x4F, 0xE0, 0x23, 0xEA, 0x38, 0x74, 0x4E, 0xF2, 0xBB, 0x8B, 0xF1, 0x21,
  0xC4, 0x25, 0xF7, 0xD5, 0xD0, 0x8F, 0x12, 0x10, 0xD8, 0x4C, 0x46, 0x8E, 0x43, 0xDB, 0x8C, 0xBA, 0x28, 0x32, 0xE9, 0xA0, 0xCB, 0xA6, 0x83, 0x2E, 0x9A, 0x0C, 0xBA, 0x68, 0x32, 0xE9, 0xA0, 0xCB, 0xA6, 0x83, 0x2E, 0x9A, 0x0C, 0xBA, 0x68, 0x32,
  0xE9, 0xA0, 0xCB, 0xA6, 0x83, 0x2E, 0x9A, 0x09, 0x93, 0x8A, 0x52, 0x09, 0x24, 0x9F, 0x58, 0xEC, 0x2E, 0x5B, 0xBC, 0xBF, 0xB1, 0x3E, 0x42, 0x63, 0xA3, 0x4C, 0xD0, 0xE1, 0xD1, 0x3A, 0xCF, 0xBC, 0xE6, 0xC4, 0x27, 0xCB, 0xD4, 0x2F, 0xA5, 0x3E,
  0x25, 0xF0, 0x0F, 0xA3, 0x86, 0x47, 0xFE, 0x46, 0x23, 0x34, 0x72, 0xDF, 0xE4, 0xA3, 0x1C, 0x42, 0x51, 0x20, 0xB4, 0xCD, 0x7D, 0x7F, 0xCF, 0x82, 0x6A, 0x33, 0xDC, 0x11, 0x99, 0x7B, 0x97, 0xE8, 0x9F, 0xFF, 0xC4, 0x00, 0x42, 0x10, 0x00, 0x00,
  0x05, 0x01, 0x04, 0x05, 0x09, 0x05, 0x06, 0x03, 0x09, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x02, 0x03, 0x04, 0x11, 0x05, 0x12, 0x34, 0x92, 0x13, 0x21, 0x22, 0x31, 0x51, 0x14, 0x32, 0x35, 0x41, 0x71, 0x74, 0x91, 0xB2, 0xD2, 0x24, 0x42,
  0x52, 0x61, 0xD1, 0x06, 0x15, 0x23, 0x30, 0x33, 0x81, 0x10, 0x62, 0xF0, 0x40, 0x44, 0x53, 0x64, 0x94, 0xA1, 0xA2, 0xC1, 0xE1, 0xFF, 0xDA, 0x00, 0x08, 0x01, 0x01, 0x00, 0x06, 0x3F, 0x02, 0x9F, 0x6A, 0x5A, 0x73, 0x9F, 0x43, 0x09, 0x7B, 0x46,
  0xCB, 0x0D, 0x1F, 0x37, 0xAF, 0xAF, 0xB4, 0x86, 0x32, 0x6E, 0x64, 0x7A, 0x46, 0x32, 0x6E, 0x64, 0x7A, 0x46, 0x32, 0x6E, 0x64, 0x7A, 0x46, 0x32, 0x6E, 0x64, 0x7A, 0x46, 0x32, 0x6E, 0x64, 0x7A, 0x46, 0x32, 0x6E, 0x64, 0x7A, 0x46, 0x32, 0x6E,
  0x64, 0x7A, 0x46, 0x32, 0x6E, 0x64, 0x7A, 0x46, 0x32, 0x6E, 0x64, 0x7A, 0x46, 0x32, 0x6E, 0x64, 0x7A, 0x46, 0x32, 0x6E, 0x64, 0x7A, 0x46, 0x32, 0x6E, 0x64, 0x7A, 0x46, 0x32, 0x6E, 0x64, 0x7A, 0x46, 0x32, 0x6E, 0x64, 0x7A, 0x46, 0x32, 0x6E,
  0x64, 0x7A, 0x46, 0x32, 0x6E, 0x64, 0x7A, 0x46, 0x32, 0x6E, 0x64, 0x7A, 0x43, 0xD6, 0x7A, 0x5F, 0x5C, 0xFB, 0x3D, 0xC6, 0x49, 0xC6, 0xDB, 0x74, 0xF9, 0xBA, 0xFF, 0x00, 0xF0, 0xC4, 0xCE, 0xF6, 0x7E, 0x44, 0x87, 0x6C, 0xFB, 0x55, 0x29, 0x65,
  0xD3, 0x55, 0xD4, 0x50, 0xA9, 0x45, 0x7C, 0x21, 0xE7, 0xE1, 0x24, 0x94, 0xEA, 0x37, 0xD4, 0xAB, 0x44, 0xF5, 0x98, 0xDB, 0xA2, 0x65, 0xB7, 0xFA, 0x89, 0x2E, 0xBF, 0x99, 0x7E, 0x7B, 0x1D, 0xD1, 0x3E, 0x65, 0x09, 0x9D, 0xEC, 0xFC, 0x89, 0x1F,
  0x78, 0x46, 0x4F, 0xB5, 0x34, 0x5B, 0x64, 0x5E, 0xFA, 0x7E, 0xA4, 0x34, 0x0F, 0x9D, 0x66, 0x34, 0x5B, 0x55, 0xF7, 0xD3, 0xC4, 0x37, 0x68, 0xC1, 0xD5, 0x15, 0x6A, 0xDD, 0xD4, 0x5C, 0x50, 0x7F, 0x20, 0xDC, 0xA6, 0x0F, 0x65, 0x5B, 0xCB, 0xAD,
  0x27, 0xC3, 0xF3, 0x98, 0xEE, 0x89, 0xF3, 0x28, 0x4E, 0xEF, 0x4A, 0xF2, 0x24, 0x5C, 0x74, 0xFD, 0xB1, 0x92, 0xA2, 0xFF, 0x00, 0x98, 0xBE, 0x20, 0xDD, 0xAD, 0x67, 0xEC, 0xB2, 0xA5, 0x54, 0xC8, 0xB7, 0x25, 0x5C, 0x3B, 0x0C, 0x6B, 0x2B, 0xCD,
  0x3A, 0x57, 0x56, 0x8E, 0xB4, 0x28, 0x2E, 0x34, 0x8A, 0xAA, 0x13, 0xBB, 0xCF, 0x89, 0x75, 0x28, 0x87, 0x48, 0x33, 0x98, 0x74, 0x83, 0x39, 0x87, 0x48, 0x33, 0x98, 0x74, 0x83, 0x39, 0x87, 0x48, 0x33, 0x98, 0x74, 0x83, 0x39, 0x87, 0x48, 0x33,
  0x98, 0x74, 0x83, 0x39, 0x87, 0x48, 0x33, 0x98, 0x74, 0x83, 0x39, 0x87, 0x48, 0x33, 0x98, 0x74, 0x83, 0x39, 0x82, 0x8A, 0x2C, 0x96, 0xDF, 0x52, 0x77, 0x92, 0x0C, 0x31, 0xDD, 0x13, 0xE6, 0x50, 0x9F, 0xDE, 0x55, 0xE4, 0x48, 0x6A, 0x4C, 0x7F,
  0xD4, 0x49, 0xEE, 0xF8, 0xBE, 0x43, 0x47, 0x25, 0x9A, 0x21, 0xE4, 0x6D, 0xB4, 0xAD, 0xE4, 0x15, 0x02, 0x2B, 0x9C, 0xAE, 0x33, 0x8E, 0x68, 0xD5, 0x77, 0x87, 0xC5, 0xFB, 0x02, 0x6E, 0x4D, 0x51, 0x70, 0xEA, 0x97, 0x13, 0xBD, 0x23, 0x1C, 0xF7,
  0x8A, 0x46, 0x39, 0xEF, 0x14, 0x8C, 0x73, 0xDE, 0x29, 0x18, 0xE7, 0xBC, 0x52, 0x31, 0xCF, 0x78, 0xA4, 0x63, 0x9E, 0xF1, 0x48, 0xC7, 0x3D, 0xE2, 0x91, 0x8E, 0x7B, 0xC5, 0x23, 0x1C, 0xF7, 0x8A, 0x46, 0x39, 0xEF, 0x14, 0x8C, 0x73, 0xDE, 0x29,
  0x18, 0xE7, 0xBC, 0x52, 0x17, 0x21, 0x87, 0x9C, 0x79, 0xC3, 0x4D, 0xCD, 0xA3, 0x2D, 0x44, 0x18, 0xEE, 0x89, 0xF3, 0x28, 0x4F, 0xEF, 0x2A, 0xF2, 0x24, 0x15, 0xA7, 0x25, 0x3B, 0x09, 0xFD, 0x14, 0x9F, 0x59, 0xFC, 0x43, 0x91, 0x46, 0x57, 0xB5,
  0xBC, 0x5A, 0xCC, 0xBD, 0xC4, 0xFD, 0x47, 0x2A, 0x90, 0x9F, 0x6C, 0x78, 0xB7, 0x1F, 0xB8, 0x9E, 0x01, 0xBB, 0x26, 0xCF, 0xDA, 0x64, 0x95, 0x43, 0x32, 0xDC, 0xB3, 0xE3, 0xD8, 0x43, 0x1C, 0xDE, 0x43, 0x18, 0xE6, 0xF2, 0x18, 0xC7, 0x37, 0x90,
  0xC6, 0x39, 0xBC, 0x86, 0x31, 0xCD, 0xE4, 0x31, 0x8E, 0x6F, 0x21, 0x8C, 0x73, 0x79, 0x0C, 0x63, 0x9B, 0xC8, 0x63, 0x1C, 0xDE, 0x43, 0x18, 0xE6, 0xF2, 0x18, 0xC7, 0x37, 0x90, 0xC6, 0x39, 0xBC, 0x86, 0x1C, 0x7D, 0x72, 0xF4, 0xB7, 0x91, 0x72,
  0xE2, 0x4A, 0x84, 0x18, 0xEE, 0x89, 0xF3, 0x28, 0x4D, 0x2F, 0xF3, 0x67, 0xE4, 0x48, 0xD2, 0x5D, 0x2D, 0x45, 0x71, 0x96, 0x8B, 0xAC, 0xC2, 0xED, 0x9B, 0x43, 0x6C, 0xAF, 0x55, 0x17, 0xBD, 0xF5, 0x71, 0xEC, 0x21, 0xF7, 0x6C, 0x43, 0xF6, 0x97,
  0x4B, 0xF1, 0x0D, 0x3E, 0xE9, 0x70, 0xED, 0x31, 0xA6, 0x79, 0x3E, 0xDA, 0xE9, 0x6D, 0x7F, 0x21, 0x7C, 0x22, 0xD0, 0x8B, 0x66, 0xDA, 0x11, 0x2C, 0x86, 0xA2, 0xAE, 0xE2, 0x50, 0xE2, 0x09, 0x6E, 0x39, 0xAC, 0xF5, 0xEB, 0xEC, 0x12, 0x60, 0xDB,
  0x6C, 0x36, 0xEB, 0x28, 0x45, 0xE6, 0xE7, 0x35, 0xA8, 0x97, 0xF2, 0xFE, 0xB8, 0x0B, 0x5A, 0x2D, 0x9D, 0x2A, 0x14, 0x76, 0xE1, 0xBA, 0x69, 0xA3, 0xC8, 0xEA, 0xBC, 0x64, 0x5D, 0x47, 0xC0, 0x19, 0xDB, 0x13, 0x20, 0xBF, 0x16, 0xEF, 0x36, 0x3A,
  0x4E, 0xF5, 0x7C, 0x08, 0x4A, 0x63, 0xEC, 0xFA, 0xD8, 0x83, 0x02, 0x31, 0xD0, 0xE5, 0xBC, 0x9B, 0xC6, 0xA1, 0x1E, 0x15, 0xA6, 0xCA, 0x2D, 0x48, 0x4F, 0xFF, 0x00, 0x7C, 0x8E, 0x8A, 0x68, 0xFB, 0x78, 0x08, 0xD6, 0x15, 0x8A, 0xD2, 0x1D, 0xB4,
  0xDF, 0xD6, 0x6B, 0x73, 0x9A, 0xD9, 0x7F, 0x5A, 0xC1, 0x4A, 0xE5, 0x11, 0xAD, 0xA4, 0x17, 0x3E, 0x33, 0x6C, 0xED, 0x7E, 0xD4, 0x22, 0x33, 0x05, 0x69, 0x30, 0xD7, 0x27, 0x96, 0xBD, 0x1F, 0xE1, 0xBA, 0x55, 0xD1, 0x99, 0xEF, 0x21, 0x1A, 0x63,
  0x76, 0x8D, 0x98, 0x96, 0xDF, 0x6D, 0x2E, 0xA4, 0x94, 0x83, 0xAD, 0x0C, 0xAB, 0xF0, 0x88, 0xEF, 0xBA, 0xEC, 0x77, 0x2D, 0x33, 0x78, 0x9B, 0x5B, 0x88, 0x46, 0xC7, 0xBC, 0x7A, 0x8B, 0xF6, 0x1F, 0x78, 0x94, 0xDB, 0x35, 0xC6, 0xB4, 0x3A, 0x7D,
  0x1D, 0xCD, 0xAA, 0x52, 0xBC, 0x01, 0x4B, 0x79, 0xA4, 0xB4, 0xF2, 0x5C, 0x36, 0x97, 0x73, 0x9A, 0x66, 0x54, 0xD6, 0x5E, 0x21, 0x8E, 0xE8, 0x9F, 0x32, 0x84, 0xCE, 0xF6, 0x7E, 0x44, 0x83, 0x35, 0x5E, 0x6E, 0x0B, 0x3F, 0xF1, 0x4F, 0xD4, 0xC2,
  0x9C, 0x61, 0xAE, 0x61, 0x13, 0x6D, 0x20, 0xB7, 0x17, 0x00, 0x76, 0xCC, 0xFA, 0xAD, 0x4A, 0x3B, 0xCD, 0x5F, 0xEB, 0x3F, 0x8B, 0xF8, 0x5A, 0x2D, 0x5A, 0x4D, 0x39, 0x61, 0x5A, 0x0D, 0xBA, 0x64, 0x6E, 0x1B, 0x97, 0x34, 0x9F, 0x3E, 0x15, 0x05,
  0x65, 0xD9, 0xD6, 0xAB, 0xB6, 0xBD, 0x91, 0x70, 0xCD, 0x6A, 0x56, 0xB4, 0xA3, 0x67, 0xEB, 0x42, 0xD5, 0xC4, 0x5B, 0xA5, 0x6F, 0x3E, 0x71, 0xD0, 0x97, 0xD7, 0xA2, 0xA1, 0x99, 0x54, 0xEF, 0x9D, 0x43, 0xD1, 0xEC, 0x59, 0xC6, 0xE4, 0x99, 0x28,
  0xBB, 0x74, 0xD6, 0xA3, 0xD4, 0x5C, 0x05, 0xA7, 0x63, 0xDB, 0x27, 0xC8, 0xDC, 0x37, 0x09, 0x49, 0x75, 0x45, 0xB2, 0x62, 0x37, 0xDD, 0x3F, 0x69, 0x2D, 0x0B, 0x41, 0x0A, 0x7A, 0xAE, 0x5E, 0x59, 0xE8, 0xD3, 0x53, 0xD4, 0x9F, 0x9F, 0x58, 0x8D,
  0x6E, 0x49, 0x6D, 0x4A, 0xB3, 0xE4, 0x26, 0xE9, 0xB8, 0x92, 0xAD, 0xDD, 0x8B, 0xA7, 0xF5, 0x05, 0x2A, 0xCC, 0xFB, 0x49, 0x31, 0x32, 0x34, 0x77, 0x5B, 0x87, 0x09, 0x46, 0x49, 0x51, 0xF1, 0x3E, 0x01, 0x97, 0xE5, 0x3A, 0xB9, 0x0F, 0x1B, 0xDA,
  0xDC, 0x59, 0xD4, 0xCF, 0xF1, 0x0C, 0x44, 0x5C, 0xC9, 0xEA, 0x44, 0xB3, 0x69, 0x26, 0xF2, 0x6F, 0xAB, 0x52, 0xE9, 0xAF, 0xA8, 0x41, 0x2B, 0x2D, 0xED, 0x3C, 0x36, 0xA4, 0xA1, 0xB4, 0xAA, 0xA6, 0x7B, 0x92, 0xAE, 0x21, 0xD9, 0x6D, 0xDB, 0x56,
  0x83, 0x97, 0x22, 0xE9, 0xB4, 0x0E, 0x3B, 0x56, 0xCC, 0xAE, 0xD6, 0x94, 0x11, 0xE8, 0xDB, 0x6D, 0x9B, 0x4B, 0x53, 0x67, 0xA3, 0x2A, 0x57, 0xE7, 0xDB, 0xAC, 0x31, 0xDD, 0x13, 0xE6, 0x50, 0xB4, 0x21, 0x38, 0xB4, 0xA2, 0x53, 0x72, 0x4D, 0x4A,
  0x69, 0x47, 0xAE, 0x94, 0x22, 0xFF, 0x00, 0xA3, 0x07, 0x73, 0x46, 0x8A, 0x9D, 0x4E, 0xED, 0x0A, 0xA6, 0x0D, 0x2B, 0x34, 0x2D, 0x27, 0xBC, 0x94, 0x28, 0x4A, 0x49, 0x17, 0x68, 0xE7, 0xA7, 0xC4, 0x12, 0xA6, 0x44, 0x8B, 0x25, 0x45, 0xB9, 0x4E,
  0x20, 0x8C, 0xFC, 0x41, 0xA2, 0x1B, 0x11, 0xE2, 0xA0, 0xF7, 0x93, 0x49, 0x24, 0xD4, 0x29, 0xD7, 0xA0, 0x41, 0x75, 0xD5, 0x6B, 0x35, 0xAD, 0x94, 0x19, 0x98, 0xD2, 0x45, 0x87, 0x0E, 0x33, 0x9B, 0xAF, 0xB4, 0xDA, 0x52, 0x7F, 0xEC, 0x0B, 0x96,
  0xC6, 0x8D, 0x2A, 0xEE, 0xE3, 0x71, 0x24, 0x66, 0x40, 0xA3, 0xA2, 0x14, 0x44, 0xB2, 0x4B, 0x27, 0x2E, 0x12, 0x0A, 0x97, 0x8B, 0x71, 0xF6, 0x85, 0x33, 0x21, 0x2D, 0x3E, 0xD2, 0xB7, 0xA1, 0xC2, 0x25, 0x11, 0x83, 0x72, 0x34, 0x18, 0x8C, 0xB8,
  0x7A, 0xAF, 0x25, 0x05, 0x51, 0xC8, 0x90, 0xC4, 0x72, 0x87, 0xFE, 0x05, 0xD2, 0xB9, 0xBE, 0xBB, 0x87, 0x45, 0xD9, 0xDF, 0xE9, 0xD1, 0xF4, 0x1C, 0x91, 0x51, 0x62, 0x9C, 0x5A, 0xD7, 0x41, 0xA3, 0x4D, 0xCF, 0x01, 0xA3, 0xD8, 0xB9, 0x4A, 0x5D,
  0xEA, 0xA0, 0xD0, 0xC5, 0x6D, 0x88, 0xCD, 0x56, 0xB7, 0x1A, 0x22, 0x49, 0x0D, 0x14, 0x1F, 0x69, 0x5B, 0x31, 0x92, 0x95, 0xE8, 0xF5, 0xD0, 0xEA, 0x7F, 0x52, 0x0C, 0xC9, 0x61, 0x82, 0x69, 0xE9, 0x05, 0x79, 0xC5, 0x27, 0xDE, 0x3E, 0x3F, 0xD8,
  0xB9, 0x63, 0x6C, 0x12, 0x65, 0x3C, 0x77, 0x56, 0xEF, 0x59, 0x97, 0x01, 0xFF, 0xC4, 0x00, 0x28, 0x10, 0x01, 0x00, 0x01, 0x02, 0x06, 0x01, 0x04, 0x02, 0x03, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x11, 0x00, 0x21, 0x31, 0x41, 0x51,
  0x61, 0xC1, 0xF0, 0x71, 0x10, 0x81, 0x91, 0xA1, 0xB1, 0xE1, 0x30, 0x40, 0xD1, 0xF1, 0xFF, 0xDA, 0x00, 0x08, 0x01, 0x01, 0x00, 0x01, 0x3F, 0x21, 0x70, 0x5E, 0x24, 0x06, 0x08, 0x10, 0x40, 0x0C, 0x8B, 0xB2, 0xFF, 0x00, 0x48, 0xC1, 0x83, 0x06,
  0x0C, 0x18, 0x30, 0x60, 0xC1, 0x83, 0x06, 0x0C, 0x18, 0x30, 0x60, 0xC6, 0x2A, 0x19, 0x75, 0x61, 0x3B, 0x36, 0x6D, 0x13, 0x6A, 0xC8, 0xD2, 0xAA, 0x59, 0xAC, 0x0D, 0x66, 0xB3, 0x93, 0xFE, 0xD4, 0x09, 0xC9, 0x5E, 0x04, 0x67, 0x14, 0xDB, 0x2F,
  0xD9, 0x1A, 0x36, 0x9F, 0xA7, 0xDB, 0xFA, 0x39, 0xF2, 0xAE, 0x6A, 0x58, 0xB0, 0xCF, 0xA5, 0xBD, 0xA9, 0x59, 0xE0, 0xCF, 0x85, 0xFE, 0x5F, 0xDD, 0x03, 0xED, 0x83, 0x3A, 0xFC, 0x86, 0x5F, 0xAA, 0x9B, 0xC9, 0xDD, 0xF2, 0x16, 0xE7, 0xF3, 0xE7,
  0x6A, 0xCB, 0x25, 0x0C, 0x22, 0x80, 0x1F, 0x80, 0x73, 0xBF, 0x92, 0x81, 0xAB, 0x49, 0x5D, 0x62, 0x8F, 0x37, 0xD9, 0xA5, 0x38, 0x46, 0x5D, 0xBB, 0x83, 0xC8, 0xDC, 0x7C, 0x34, 0x8D, 0xB8, 0x42, 0x5B, 0xED, 0x46, 0x67, 0x9D, 0xBF, 0x94, 0x42,
  0x10, 0x84, 0x21, 0x08, 0x42, 0x10, 0x88, 0x2C, 0x4C, 0xEA, 0x1A, 0xC7, 0xAE, 0x71, 0x6C, 0x23, 0xEC, 0xA3, 0x35, 0xB3, 0x53, 0xA0, 0x4E, 0xA5, 0x30, 0x77, 0x38, 0xAD, 0x9F, 0x03, 0x11, 0xF9, 0x5F, 0x3E, 0x1A, 0x95, 0xEA, 0x4B, 0x0D, 0x6C,
  0x72, 0x6B, 0xB9, 0x71, 0x5D, 0xCB, 0x8A, 0xEE, 0x5C, 0x57, 0x72, 0xE2, 0xBB, 0x97, 0x15, 0xDC, 0xB8, 0xAE, 0xE5, 0xC5, 0x77, 0x2E, 0x2B, 0xB9, 0x71, 0x5D, 0xCB, 0x8A, 0xEE, 0x5C, 0x57, 0x72, 0xE2, 0xAE, 0xC8, 0x51, 0xC2, 0x22, 0xE0, 0x6C,
  0x7A, 0xE7, 0x17, 0x88, 0x7D, 0x6F, 0x81, 0xF8, 0x19, 0x6F, 0xE2, 0xB7, 0x42, 0x7D, 0xDB, 0x3F, 0x2C, 0xBE, 0x74, 0xAC, 0x10, 0xE0, 0x4B, 0xF3, 0x1C, 0x5F, 0x8C, 0xA9, 0x0B, 0xBC, 0x95, 0x8E, 0x29, 0xED, 0x8E, 0x95, 0xD3, 0xB9, 0xAE, 0x9D,
  0xCD, 0x74, 0xEE, 0x6B, 0xA7, 0x73, 0x5D, 0x3B, 0x9A, 0xE9, 0xDC, 0xD7, 0x4E, 0xE6, 0xBA, 0x77, 0x35, 0xD3, 0xB9, 0xAE, 0x9D, 0xCD, 0x74, 0xEE, 0x6B, 0xA7, 0x73, 0x41, 0x70, 0x5E, 0x34, 0xB8, 0xCB, 0x7D, 0xBE, 0xFD, 0x33, 0x93, 0x97, 0x11,
  0xA5, 0x74, 0x17, 0x08, 0xAC, 0x58, 0xF0, 0x67, 0x53, 0x05, 0x3C, 0xC7, 0x51, 0x86, 0xE6, 0xD4, 0xCD, 0x2C, 0x0C, 0x53, 0xE4, 0xE9, 0x1E, 0x4A, 0x84, 0x2C, 0xD3, 0xD9, 0x1C, 0xFE, 0xA9, 0x03, 0xB2, 0x16, 0x61, 0x60, 0x7C, 0xA3, 0x09, 0x31,
  0xA8, 0x41, 0x5A, 0xC7, 0x48, 0x58, 0x46, 0x22, 0xB8, 0x11, 0xE4, 0x50, 0x8A, 0x6C, 0xFD, 0xE0, 0x22, 0xE6, 0xA9, 0x5E, 0x88, 0x15, 0x83, 0x0C, 0xB6, 0x31, 0xD6, 0xAF, 0xCF, 0x36, 0x7C, 0xB0, 0x82, 0x25, 0xE1, 0x42, 0x30, 0xC5, 0xBC, 0x52,
  0xFD, 0xE8, 0xF9, 0xB4, 0x40, 0x86, 0x89, 0x7C, 0x9C, 0xA8, 0x86, 0xC1, 0x77, 0x44, 0xB8, 0x6B, 0x02, 0xA7, 0x03, 0x26, 0x6C, 0xA4, 0x64, 0x22, 0xC0, 0x6C, 0xFC, 0x83, 0x6A, 0x18, 0x26, 0x94, 0xAC, 0x19, 0x0C, 0xD2, 0xE5, 0x03, 0xA3, 0x8E,
  0x22, 0x03, 0x0E, 0xF7, 0xA6, 0x08, 0xE7, 0xAC, 0x6E, 0x26, 0x70, 0x0C, 0x35, 0xA1, 0x59, 0xD9, 0x82, 0xC3, 0xE1, 0x26, 0x37, 0xF7, 0xA1, 0xCC, 0x69, 0x28, 0x45, 0x73, 0x02, 0x07, 0xDF, 0xA6, 0x77, 0x2F, 0x4A, 0x53, 0x2B, 0x14, 0x37, 0xF0,
  0xEF, 0xF5, 0x47, 0xC6, 0xC2, 0x2F, 0xB6, 0x96, 0xC5, 0x4F, 0x83, 0x43, 0x16, 0x73, 0xE3, 0xE7, 0x4F, 0x42, 0xCB, 0xAB, 0x04, 0x5D, 0x62, 0x56, 0x38, 0x5E, 0x66, 0x5A, 0x96, 0x03, 0xF5, 0x24, 0x92, 0x16, 0xC4, 0x5E, 0x58, 0xD2, 0x77, 0xF5,
  0x36, 0x51, 0x0E, 0xD4, 0xE1, 0x1A, 0x9C, 0x21, 0x2C, 0x10, 0x27, 0x3D, 0x6D, 0x53, 0xF7, 0x02, 0xE5, 0x04, 0xC7, 0x44, 0x84, 0x70, 0xC6, 0xA0, 0xC3, 0x2A, 0x38, 0xD8, 0x32, 0xB3, 0x44, 0x5B, 0xE0, 0x55, 0x46, 0xF0, 0x2C, 0xBC, 0x90, 0x43,
  0x31, 0x62, 0xB1, 0xAA, 0xA4, 0x26, 0xB6, 0xE3, 0x35, 0xE6, 0xF6, 0xB5, 0x41, 0xF4, 0x31, 0x58, 0x12, 0x5C, 0xED, 0x05, 0x12, 0xAB, 0xC1, 0x58, 0x47, 0xDF, 0x34, 0x35, 0x4D, 0x66, 0x10, 0xE1, 0x6E, 0x9A, 0x6A, 0x5E, 0x0A, 0x44, 0x9B, 0x51,
  0x21, 0x50, 0x26, 0x8B, 0x09, 0x0C, 0xCB, 0x70, 0x27, 0xD3, 0x3C, 0x4B, 0xD2, 0x01, 0xBB, 0x47, 0x92, 0xAF, 0xDB, 0xCA, 0x03, 0xBD, 0x63, 0x84, 0xA4, 0x23, 0xED, 0x43, 0x83, 0x2C, 0x00, 0xB5, 0x7F, 0xC4, 0x51, 0x42, 0x68, 0x1B, 0x9A, 0x4A,
  0xF5, 0x7C, 0x30, 0x49, 0x4D, 0xE3, 0x1A, 0x7A, 0x6B, 0x2A, 0x6D, 0x55, 0x25, 0xAB, 0x2A, 0x1C, 0x0F, 0xE9, 0x22, 0x86, 0x70, 0xC7, 0x8A, 0xD7, 0x12, 0x85, 0xE9, 0x9E, 0x2D, 0x2D, 0x6B, 0xEF, 0x23, 0x5C, 0x43, 0x6A, 0x34, 0xB0, 0xAB, 0x49,
  0xC4, 0x9C, 0x8A, 0x22, 0x5D, 0x25, 0xED, 0xDE, 0x0E, 0x37, 0xF4, 0xC4, 0x4C, 0xBE, 0x15, 0x01, 0xD6, 0xD8, 0xA5, 0xEE, 0x6D, 0xBD, 0x08, 0x8D, 0x28, 0xE8, 0xCA, 0xBB, 0xF7, 0x16, 0x0A, 0xC3, 0x2D, 0x9C, 0x19, 0xD2, 0xDA, 0x7D, 0xD4, 0xF2,
  0x20, 0xA3, 0x89, 0x93, 0x09, 0xFC, 0xFF, 0x00, 0x48, 0xEB, 0x21, 0x21, 0x41, 0x11, 0x76, 0x07, 0x8A, 0xFF, 0xDA, 0x00, 0x0C, 0x03, 0x01, 0x00, 0x02, 0x00, 0x03, 0x00, 0x00, 0x00, 0x10, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x4F, 0x74,
  0x92, 0x49, 0x24, 0x92, 0x48, 0x03, 0x34, 0xC9, 0x24, 0x92, 0x49, 0x24, 0x03, 0x3A, 0x92, 0x49, 0x24, 0x92, 0x48, 0x87, 0x9E, 0x40, 0x00, 0x00, 0x00, 0x00, 0x83, 0x29, 0x54, 0x92, 0x49, 0x24, 0x92, 0x01, 0xA8, 0x2C, 0x02, 0x41, 0x24, 0x00,
  0x40, 0xD1, 0x92, 0x08, 0x24, 0x02, 0x01, 0x00, 0x0C, 0x78, 0x24, 0x90, 0x48, 0x04, 0x90, 0x49, 0x24, 0x92, 0x49, 0x24, 0x92, 0x48, 0x3F, 0xFF, 0xC4, 0x00, 0x29, 0x11, 0x00, 0x01, 0x02, 0x04, 0x05, 0x03, 0x05, 0x01, 0x01, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x61, 0x11, 0x21, 0x51, 0xD1, 0x31, 0x41, 0x91, 0xA1, 0xF1, 0x71, 0x81, 0xE1, 0x10, 0x40, 0xB1, 0xC1, 0xF0, 0x30, 0x50, 0xFF, 0xDA, 0x00, 0x08, 0x01, 0x03, 0x01, 0x01, 0x3F, 0x10, 0xF6, 0x81, 0x6C, 0x10,
  0xC0, 0x65, 0x03, 0x4B, 0x1B, 0xA1, 0x17, 0x10, 0xD8, 0x66, 0x56, 0x5A, 0x62, 0x0F, 0xB1, 0xFB, 0x1F, 0x63, 0x23, 0xEB, 0x38, 0xB8, 0xF8, 0xEC, 0x87, 0x13, 0xA8, 0xE2, 0xB7, 0xF2, 0xB1, 0x70, 0x9E, 0x49, 0x8E, 0x5E, 0x11, 0x4B, 0x91, 0xD8,
  0xD0, 0xFF, 0x00, 0x79, 0x09, 0x06, 0x3D, 0x51, 0xDE, 0xEE, 0xA4, 0xA6, 0x47, 0x43, 0x4E, 0x87, 0xC5, 0x14, 0x70, 0x44, 0x64, 0x11, 0x43, 0x71, 0x88, 0xD5, 0x19, 0x4E, 0xF8, 0x32, 0x07, 0x19, 0xF0, 0xB9, 0x05, 0xC8, 0x2E, 0x41, 0x72, 0x0B,
  0x90, 0x5C, 0x82, 0xE4, 0x17, 0x20, 0xB9, 0x05, 0xC8, 0x2E, 0x41, 0x72, 0x08, 0xB1, 0x02, 0x21, 0x43, 0xE9, 0x8C, 0xB1, 0x28, 0x1B, 0xB7, 0x75, 0x80, 0xE0, 0x4C, 0x1C, 0xA3, 0xF6, 0x11, 0xE4, 0x56, 0x81, 0xBF, 0x6C, 0xFB, 0xA1, 0x59, 0x50,
  0xC0, 0x8C, 0x42, 0x7F, 0xB5, 0x93, 0xFD, 0xAC, 0x9F, 0xED, 0x64, 0xFF, 0x00, 0x6B, 0x27, 0xFB, 0x59, 0x3F, 0xDA, 0xC9, 0xFE, 0xD6, 0x4F, 0xF6, 0xB2, 0x7F, 0xB5, 0x93, 0xFD, 0xAC, 0x9F, 0xED, 0x64, 0xFF, 0x00, 0x6B, 0x23, 0x63, 0x88, 0x88,
  0x4E, 0x1F, 0x5E, 0x98, 0xCA, 0x20, 0x0E, 0x43, 0x03, 0xD7, 0xB6, 0x4F, 0xD1, 0x4E, 0x2F, 0xA8, 0x5C, 0xE5, 0xAD, 0x14, 0x86, 0xFA, 0x05, 0x3A, 0xD7, 0x44, 0x27, 0x3E, 0x2D, 0x4D, 0x7A, 0x0F, 0x34, 0x4C, 0x34, 0x29, 0x96, 0x85, 0x32, 0xD0,
  0xA6, 0x5A, 0x14, 0xCB, 0x42, 0x99, 0x68, 0x53, 0x2D, 0x0A, 0x65, 0xA1, 0x4C, 0xB4, 0x29, 0x96, 0x85, 0x32, 0xD0, 0xA6, 0x5A, 0x15, 0x13, 0x24, 0x44, 0x20, 0x07, 0xA1, 0x11, 0x10, 0x2A, 0x4E, 0xE1, 0x20, 0xF8, 0xEC, 0x11, 0x9C, 0xD1, 0x19,
  0x39, 0xAF, 0x41, 0x97, 0x84, 0x48, 0xCD, 0x66, 0x07, 0x2E, 0xA7, 0xE3, 0xAA, 0x14, 0x16, 0xA3, 0x0A, 0x5F, 0xC7, 0xF7, 0x32, 0x41, 0x12, 0x65, 0xB0, 0x2E, 0x7F, 0x60, 0x8C, 0x70, 0xD0, 0x00, 0x64, 0x29, 0xD9, 0x62, 0xF8, 0x93, 0x18, 0xB3,
  0x3F, 0x92, 0xD6, 0x9E, 0xC6, 0x2F, 0x0C, 0x22, 0x80, 0xC0, 0x88, 0x40, 0x00, 0x20, 0x3F, 0xC3, 0xFF, 0xC4, 0x00, 0x29, 0x11, 0x00, 0x01, 0x02, 0x04, 0x05, 0x03, 0x05, 0x01, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x61,
  0x11, 0x21, 0x51, 0xD1, 0x31, 0x41, 0x91, 0xA1, 0xF1, 0x71, 0x81, 0xE1, 0x10, 0x40, 0xB1, 0xC1, 0xF0, 0x30, 0x50, 0xFF, 0xDA, 0x00, 0x08, 0x01, 0x02, 0x01, 0x01, 0x3F, 0x10, 0xF6, 0x87, 0x64, 0xC0, 0x89, 0xCE, 0x22, 0xB7, 0x16, 0x44, 0x82,
  0x05, 0xB9, 0xC8, 0x2C, 0xC4, 0xC0, 0x3F, 0x47, 0xF4, 0xC7, 0xB1, 0x9D, 0xB4, 0x98, 0xD8, 0xFC, 0xF7, 0x44, 0x85, 0xD0, 0x63, 0x4B, 0x78, 0x58, 0x31, 0x47, 0x73, 0x40, 0x71, 0x9F, 0x94, 0x2A, 0xE6, 0x37, 0x15, 0x1F, 0xDF, 0x01, 0x1A, 0x19,
  0x41, 0x9A, 0xCC, 0xA6, 0x00, 0x03, 0x51, 0x5E, 0xA3, 0xCD, 0x54, 0x2E, 0x0C, 0x26, 0x03, 0x51, 0x63, 0x81, 0xD1, 0x00, 0xCA, 0xF9, 0x33, 0x26, 0x39, 0x72, 0xB8, 0x85, 0xC4, 0x2E, 0x21, 0x71, 0x0B, 0x88, 0x5C, 0x42, 0xE2, 0x17, 0x10, 0xB8,
  0x85, 0xC4, 0x2E, 0x21, 0x71, 0x08, 0x18, 0x26, 0x03, 0x51, 0xE9, 0x84, 0xB0, 0xB8, 0x3B, 0x3F, 0x65, 0x88, 0x21, 0x48, 0x8C, 0xE1, 0xF4, 0x50, 0x3C, 0x36, 0x88, 0xB7, 0x7C, 0xBB, 0x22, 0x59, 0xD1, 0xC4, 0x1C, 0x0A, 0x65, 0xBD, 0xD3, 0x2D,
  0xEE, 0x99, 0x6F, 0x74, 0xCB, 0x7B, 0xA6, 0x5B, 0xDD, 0x32, 0xDE, 0xE9, 0x96, 0xF7, 0x4C, 0xB7, 0xBA, 0x65, 0xBD, 0xD3, 0x2D, 0xEE, 0x99, 0x6F, 0x74, 0xCB, 0x7B, 0xA0, 0xE0, 0x80, 0x18, 0xCA, 0x3F, 0x7E, 0x98, 0x4A, 0x08, 0x96, 0x67, 0x13,
  0x53, 0xBE, 0x6D, 0xD5, 0x49, 0x2F, 0xB0, 0xD8, 0x67, 0xA5, 0x54, 0xF6, 0xFB, 0x0D, 0x7A, 0x53, 0x55, 0x27, 0x08, 0x34, 0x14, 0xEA, 0x7C, 0x55, 0x3C, 0xD4, 0x27, 0xDA, 0x84, 0xFB, 0x50, 0x9F, 0x6A, 0x13, 0xED, 0x42, 0x7D, 0xA8, 0x4F, 0xB5,
  0x09, 0xF6, 0xA1, 0x3E, 0xD4, 0x27, 0xDA, 0x84, 0xFB, 0x50, 0x9F, 0x6A, 0x14, 0x38, 0x90, 0x31, 0x89, 0x31, 0xD3, 0xD0, 0x18, 0x18, 0x85, 0x38, 0x71, 0x99, 0x36, 0x67, 0xA9, 0xC9, 0x00, 0xC9, 0x94, 0xD8, 0x53, 0xA9, 0xCF, 0xCA, 0x1C, 0x2A,
  0x94, 0x73, 0x23, 0x3E, 0x83, 0xE7, 0xA2, 0x2C, 0x66, 0x83, 0x9A, 0xDB, 0xCF, 0xF7, 0x13, 0x45, 0x00, 0x27, 0xBC, 0x6C, 0x3F, 0x62, 0x82, 0x31, 0xD1, 0x24, 0xE6, 0x6B, 0xDC, 0xAC, 0x2E, 0x80, 0x21, 0x06, 0x43, 0xF2, 0x7A, 0x57, 0xD8, 0xC0,
  0xE3, 0x26, 0x08, 0x8C, 0x48, 0x14, 0x49, 0x26, 0x27, 0xFC, 0x3F, 0xFF, 0xC4, 0x00, 0x24, 0x10, 0x01, 0x01, 0x00, 0x02, 0x02, 0x01, 0x04, 0x02, 0x03, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x11, 0x00, 0x21, 0x31, 0x41, 0x51, 0x10,
  0x61, 0xD1, 0xF0, 0x30, 0x71, 0x40, 0x81, 0x91, 0xC1, 0xFF, 0xDA, 0x00, 0x08, 0x01, 0x01, 0x00, 0x01, 0x3F, 0x10, 0x2C, 0x6E, 0xA6, 0xE4, 0x00, 0xC4, 0xD5, 0x50, 0x6F, 0x3F, 0xC1, 0x1A, 0x34, 0x68, 0xD1, 0xA3, 0x46, 0x8D, 0x1A, 0x34, 0x68,
  0xD1, 0xA3, 0x46, 0x8D, 0x1A, 0xC2, 0xC4, 0x72, 0xAE, 0x00, 0x30, 0x2C, 0xD4, 0x14, 0x94, 0x25, 0x92, 0x0B, 0xA0, 0x59, 0x8C, 0xD5, 0x40, 0x7A, 0x67, 0x2B, 0x1A, 0x79, 0xD8, 0x56, 0x22, 0xA4, 0x4E, 0x7D, 0xDA, 0x7C, 0x49, 0x6D, 0x85, 0x7A,
  0xC1, 0x18, 0x13, 0x5C, 0x1E, 0x17, 0xF4, 0x27, 0x90, 0xE1, 0xAF, 0xE0, 0x6D, 0xF2, 0xB5, 0xE4, 0x6B, 0x37, 0x31, 0x39, 0x0D, 0x9D, 0xB4, 0x6D, 0x06, 0x1C, 0x68, 0x48, 0xF0, 0x27, 0xB7, 0x60, 0xF9, 0x47, 0xA0, 0x2F, 0x70, 0x73, 0xF3, 0x10,
  0x74, 0x0B, 0xE0, 0x1A, 0xD9, 0x5D, 0x40, 0xB9, 0x04, 0x3C, 0x7E, 0x93, 0xFD, 0x22, 0x69, 0x1F, 0xCF, 0xB5, 0x4C, 0x50, 0x09, 0xC8, 0xE4, 0x5D, 0x74, 0x18, 0x3C, 0x40, 0xF7, 0xE2, 0x38, 0xF0, 0x30, 0x7D, 0x5D, 0xEA, 0x92, 0x67, 0x4E, 0x87,
  0x05, 0xD1, 0x84, 0x7E, 0x93, 0x09, 0x01, 0xA7, 0x53, 0x41, 0xFE, 0x98, 0xE5, 0xDA, 0x42, 0xF5, 0x05, 0xD6, 0xE0, 0xBC, 0x0D, 0xC5, 0x9F, 0x6D, 0xF1, 0x9F, 0x6D, 0xF1, 0x9F, 0x6D, 0xF1, 0x9F, 0x6D, 0xF1, 0x9F, 0x6D, 0xF1, 0x9F, 0x6D, 0xF1,
  0x9F, 0x6D, 0xF1, 0x9F, 0x6D, 0xF1, 0x9F, 0x6D, 0xF1, 0x9F, 0x6D, 0xF1, 0x9F, 0x6D, 0xF1, 0x9F, 0x6D, 0xF1, 0x86, 0xB0, 0x44, 0x56, 0x65, 0x72, 0x97, 0x57, 0x8F, 0x5D, 0xAB, 0x05, 0x98, 0xA0, 0x6A, 0xBD, 0x08, 0xE4, 0x35, 0x39, 0xE1, 0x36,
  0x0E, 0x36, 0x2C, 0x89, 0x18, 0x4A, 0xC6, 0x87, 0xEC, 0xE1, 0xA3, 0x8C, 0x45, 0x09, 0x6F, 0x2A, 0x33, 0xC0, 0x0D, 0x86, 0x92, 0x2A, 0x23, 0x8F, 0xE5, 0x36, 0x11, 0xE0, 0x21, 0x20, 0x14, 0x48, 0xC1, 0xE4, 0x1F, 0xCA, 0x4C, 0x99, 0x32, 0x64,
  0xC9, 0x93, 0x26, 0x4C, 0x99, 0x32, 0x69, 0x8C, 0xF3, 0x8C, 0x00, 0x2D, 0xAE, 0xE7, 0xC6, 0xBD, 0x76, 0xAC, 0xDC, 0x4A, 0xF8, 0x87, 0x45, 0x8F, 0x60, 0x9E, 0x41, 0x75, 0x15, 0x9A, 0x09, 0x3A, 0x0E, 0x42, 0x71, 0xB4, 0xEC, 0x17, 0x47, 0x60,
  0x80, 0x09, 0x76, 0x1C, 0x4F, 0x6E, 0xAF, 0x0C, 0x3B, 0x2A, 0x62, 0xD7, 0x6A, 0xB4, 0x0E, 0x91, 0x6F, 0x0C, 0x76, 0xFC, 0xA0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x55, 0x59, 0x0F, 0x46, 0xCD, 0x55, 0x34, 0x09, 0xDB,
  0x7D, 0x39, 0xB4, 0x89, 0xA9, 0x1E, 0x47, 0x38, 0x65, 0x99, 0x64, 0xA0, 0xC3, 0x82, 0x2A, 0x38, 0x0F, 0x28, 0x3D, 0x19, 0x2A, 0x80, 0xF5, 0xE3, 0x48, 0x03, 0x50, 0x0D, 0x4A, 0x69, 0x59, 0x65, 0x2F, 0x52, 0xDC, 0x1F, 0xD8, 0xBC, 0xA1, 0x41,
  0x03, 0x58, 0xAB, 0x45, 0x1E, 0x78, 0x59, 0xCB, 0x0D, 0x81, 0x40, 0x40, 0xF8, 0x8E, 0x45, 0x9B, 0xA8, 0x84, 0xFB, 0x6F, 0x19, 0x0A, 0x22, 0x63, 0x9C, 0x8B, 0xC8, 0x34, 0x84, 0x44, 0xCE, 0x36, 0xD0, 0x6D, 0x1C, 0x94, 0x2D, 0x33, 0x6E, 0xBC,
  0x0A, 0x7B, 0x1A, 0x7D, 0xE8, 0x10, 0x0D, 0xAF, 0x63, 0x5D, 0x85, 0xF9, 0x02, 0x12, 0x0E, 0x2F, 0xB1, 0xB0, 0x50, 0x46, 0x18, 0xC7, 0x5F, 0x56, 0x78, 0xED, 0xA5, 0x1C, 0x3B, 0xD1, 0xC1, 0xD3, 0x7B, 0xE1, 0x03, 0x96, 0xC3, 0xAA, 0x04, 0xDB,
  0x18, 0x01, 0xD9, 0xC0, 0xAE, 0x52, 0xE7, 0x54, 0x51, 0x46, 0xCB, 0x24, 0xA1, 0x34, 0x6A, 0xB5, 0x45, 0x7B, 0x75, 0x77, 0x3A, 0xC1, 0x47, 0x22, 0xA4, 0x04, 0x00, 0x05, 0x8A, 0x5E, 0xDC, 0x4C, 0xF3, 0xDC, 0x4C, 0x20, 0xDA, 0xE5, 0x05, 0x50,
  0x1A, 0xC0, 0x0E, 0x44, 0x56, 0xFB, 0xB2, 0xFA, 0x49, 0x4C, 0x1C, 0xE7, 0xB0, 0x40, 0xA2, 0x54, 0xA8, 0x56, 0x26, 0xDE, 0x9B, 0x4D, 0x7B, 0x12, 0xC2, 0xBF, 0xA7, 0x1B, 0xA1, 0xCE, 0x0E, 0xB1, 0xEA, 0xC6, 0xF9, 0x91, 0xE4, 0x26, 0x0C, 0x49,
  0xAA, 0x32, 0xA7, 0xB6, 0x2F, 0xBA, 0x05, 0xDD, 0xC2, 0xEC, 0xBF, 0xAA, 0xD5, 0x1B, 0xE1, 0xBF, 0xBD, 0x1C, 0x2F, 0x44, 0x2E, 0xA5, 0x4D, 0x45, 0xD8, 0x85, 0x88, 0x41, 0x15, 0x51, 0x7A, 0xD0, 0x24, 0x91, 0x62, 0x81, 0xAA, 0xD2, 0x97, 0x86,
  0x17, 0x9A, 0x72, 0x98, 0x77, 0xA0, 0x72, 0x98, 0x93, 0x45, 0x78, 0xC6, 0x86, 0x8B, 0x5B, 0x85, 0x35, 0x71, 0x70, 0x30, 0x45, 0x93, 0x40, 0xCB, 0xFF, 0x00, 0x61, 0xA4, 0x65, 0x49, 0x33, 0x53, 0x68, 0xDF, 0x2F, 0xB0, 0x04, 0x80, 0xBB, 0x30,
  0x8C, 0x89, 0x68, 0xBB, 0x53, 0xD9, 0x6D, 0xEC, 0x0D, 0x90, 0xC0, 0xF3, 0x59, 0x1E, 0xCA, 0x14, 0x50, 0x41, 0x85, 0xE7, 0x8F, 0xEA, 0x6F, 0xDC, 0x0A, 0x3B, 0xD1, 0x83, 0xE7, 0x4A, 0x4C, 0xC0, 0x08, 0x24, 0xA0, 0xA6, 0x54, 0x94, 0xDC, 0x48,
  0xE3, 0x2D, 0x73, 0xD2, 0x4D, 0x4C, 0x0C, 0x31, 0x0E, 0x17, 0x39, 0x9C, 0x20, 0xEB, 0x5A, 0x70, 0x54, 0x0A, 0xF1, 0x68, 0x33, 0x94, 0x2B, 0xB7, 0x7D, 0xCF, 0x4D, 0xA0, 0x2D, 0xF0, 0xB1, 0xBA, 0x35, 0x06, 0x27, 0x08, 0x5E, 0x4C, 0x94, 0xCE,
  0xC3, 0xB0, 0x73, 0x29, 0x57, 0x97, 0x78, 0x79, 0x86, 0x09, 0xFC, 0xC5, 0x69, 0xC3, 0x72, 0x20, 0x40, 0x0E, 0x00, 0xBA, 0x33, 0xEB, 0xDF, 0xF7, 0x3D, 0x91, 0xB6, 0x94, 0x81, 0x07, 0xB5, 0x98, 0xB5, 0x34, 0x1C, 0x97, 0x0C, 0xCA, 0xF7, 0x6B,
  0x88, 0xB3, 0x2B, 0xD5, 0xCA, 0xD4, 0xF7, 0x5C, 0xDC, 0xE8, 0xEC, 0xC3, 0x98, 0x8C, 0x7C, 0x5C, 0x59, 0x00, 0x43, 0x83, 0xB4, 0x7D, 0x0F, 0x81, 0x30, 0x95, 0xF6, 0x8E, 0xC5, 0x49, 0xBA, 0x20, 0xAB, 0x14, 0xE1, 0x98, 0x78, 0xB2, 0x01, 0x5F,
  0xB6, 0xBF, 0xB3, 0x22, 0x2C, 0x28, 0xC4, 0x80, 0x85, 0x41, 0x44, 0x20, 0x9C, 0xE1, 0x90, 0x00, 0xD2, 0x51, 0x0A, 0x15, 0x5B, 0xB1, 0xCE, 0xFD, 0x01, 0x1F, 0x8B, 0x2A, 0x95, 0xA0, 0xD1, 0x6D, 0x6C, 0xEF, 0x10, 0xA7, 0x77, 0x4D, 0xE3, 0xD9,
  0x69, 0xA9, 0xC4, 0xC1, 0xC4, 0x84, 0x47, 0xA8, 0xC2, 0xBD, 0xB3, 0xAC, 0xD2, 0x56, 0x67, 0x08, 0x83, 0x5B, 0x17, 0xF0, 0xC3, 0xBC, 0x04, 0x54, 0x62, 0x5C, 0x2A, 0xE5, 0x4A, 0xA0, 0x2A, 0xAD, 0x55, 0xFE, 0x13, 0x3E, 0x87, 0x2E, 0xD0, 0x52,
  0x59, 0xA8, 0x01, 0x41, 0x6C, 0x27, 0xFF, 0xD9, 0x00
};

/*********************************************************************
*
*       Static code
*
**********************************************************************
*/
/*********************************************************************
*
*       _cbWin
*/
static void _cbWin(WM_MESSAGE * pMsg) {
  static GUI_JPEG_INFO     Info;
  static GUI_MEMDEV_Handle hMem;
  static GUI_MEMDEV_Handle hMemB;

  switch (pMsg->MsgId) {
  case WM_CREATE:
    //
    // Get info about the JPEG image
    //
    GUI_JPEG_GetInfo(acseggerlogo, sizeof(acseggerlogo), &Info);
    //
    // Create memory device
    // A fixed color depth with 32bpp is necessary for blurring
    //
    hMem = GUI_MEMDEV_CreateFixed32(0, 0, Info.XSize, Info.YSize);
    //
    // Select the memory device
    //
    GUI_MEMDEV_Select(hMem);
    //
    // Execute drawing operation
    //
    GUI_JPEG_Draw(acseggerlogo, sizeof(acseggerlogo), 0, 0);
    //
    // Clear selection of memory device
    //
    GUI_MEMDEV_Select(0);
    break;
  case WM_PAINT:
    GUI_SetBkColor(GUI_BLACK);
    GUI_Clear();
    //
    // Select the memory device
    //
    GUI_MEMDEV_Select(hMemB);
    GUI_SetBkColor(GUI_BLACK);
    GUI_Clear();
    //
    // Clear selection of memory device
    //
    GUI_MEMDEV_Select(0);
    //
    // Execute blurring operation
    // Creates a blurred copy of the first memory device
    //
    hMemB = GUI_MEMDEV_CreateBlurredDevice32HQ(hMem, BLURRING_DEPTH);
    //
    // Copy memory device to the display
    //
    GUI_MEMDEV_CopyToLCDAt(hMemB, 0, 0);
    //
    // Execute blending operation
    //
    GUI_MEMDEV_BlendColor32(hMemB, BLENDING_COLOR, BLENDING_INTENSITY);
    //
    // Copy memory device to the display
    //
    GUI_MEMDEV_CopyToLCDAt(hMemB, 0, Info.YSize + 10);
    break;
  default:
    WM_DefaultProc(pMsg);
    break;
  }
}

/*********************************************************************
*
*       Public code
*
**********************************************************************
*/
/*********************************************************************
*
*       MainTask
*/
void MainTask(void) {
  GUI_Init();

  //
  // Create window
  //
  WM_CreateWindow(0, 0, LCD_GetXSize(), LCD_GetYSize(), WM_CF_SHOW, _cbWin, 0);

  while (1) {
    GUI_Delay(100);
  }
}

/*************************** End of file ****************************/

